import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterOutlet } from '@angular/router';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [CommonModule, RouterOutlet],
  templateUrl: './app.component.html',
  styleUrl: './app.component.scss'
})
export class AppComponent {
  length = 0;
  includeLetters = false;
  includeNumbers = false;
  includeSymbols = false;
  generateBtnEnabled = false;
  password = "";

  onChangeIncludeLetters() {
    this.includeLetters = !this.includeLetters;
    this.generateBtnEnabled = true;
  }

  onChangeIncludeNumbers() {
    this.includeNumbers = !this.includeNumbers;
  }

  onChangeIncludeSymbols() {
    this.includeSymbols = !this.includeSymbols;
  }
  onButtonClick() {
    this.generatePassword();
  }

  onChangeLength($event: Event) {
    const target = $event.target as HTMLInputElement;
    const parsedValue = parseInt(target.value);

    if (!isNaN(parsedValue)) {
      this.length = parsedValue;
    } else {
      this.length = 0;
    }
  }

  generatePassword() {
    const numbers : string = '1234567890';
    const letters : string = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    const symbols : string = '!@#$%^&*()';

    let validChars : string = '';

    if (this.includeLetters) {
      validChars += letters;
    }

    if (this.includeNumbers) {
      validChars += numbers;
    }

    if (this.includeSymbols) {
      validChars += symbols;
    }

    let generatedPassword = '';

    for (let i = 0; i < this.length; i++) {
      const index = Math.floor(Math.random() * validChars.length);
      generatedPassword += validChars[index];
    }

    this.password = generatedPassword;
  }
}
